==> igniteui-webcomponents-layouts-5.0.1.tgz: package/esm2015/lib/igc-tool-action-icon-button-component.js <==
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionIconButton } from "./ToolActionIconButton";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
export let IgcToolActionIconButtonComponent = /*@__PURE__*/ (() => {
    class IgcToolActionIconButtonComponent extends IgcToolActionComponent {
        createImplementation() {
            return new ToolActionIconButton();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent == null) {
                let names = getAllPropertyNames(IgcToolActionIconButtonComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent = names;
            }
            return IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent;
        }
        static register() {
            if (!IgcToolActionIconButtonComponent._isElementRegistered) {
                IgcToolActionIconButtonComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcToolActionIconButtonComponent.htmlTagName, IgcToolActionIconButtonComponent);
            }
        }
        /**
         * Gets or sets how long it takes before the tooltip is displayed (in milliseconds).
        */
        get tooltipDelay() {
            return this.i.ib;
        }
        set tooltipDelay(v) {
            this.i.ib = +v;
            this._a("tooltipDelay", this.i.ib);
        }
        /**
         * Gets the actual delay before the tooltip is displayed (in milliseconds).
        */
        get actualTooltipDelay() {
            return this.i.ia;
        }
        set actualTooltipDelay(v) {
            this.i.ia = +v;
            this._a("actualTooltipDelay", this.i.ia);
        }
        get contentPaddingLeft() {
            return this.i.h3;
        }
        set contentPaddingLeft(v) {
            this.i.h3 = +v;
            this._a("contentPaddingLeft", this.i.h3);
        }
        get actualContentPaddingLeft() {
            return this.i.hz;
        }
        set actualContentPaddingLeft(v) {
            this.i.hz = +v;
            this._a("actualContentPaddingLeft", this.i.hz);
        }
        get contentPaddingTop() {
            return this.i.h5;
        }
        set contentPaddingTop(v) {
            this.i.h5 = +v;
            this._a("contentPaddingTop", this.i.h5);
        }
        get actualContentPaddingTop() {
            return this.i.h1;
        }
        set actualContentPaddingTop(v) {
            this.i.h1 = +v;
            this._a("actualContentPaddingTop", this.i.h1);
        }
        get contentPaddingRight() {
            return this.i.h4;
        }
        set contentPaddingRight(v) {
            this.i.h4 = +v;
            this._a("contentPaddingRight", this.i.h4);
        }
        get actualContentPaddingRight() {
            return this.i.h0;
        }
        set actualContentPaddingRight(v) {
            this.i.h0 = +v;
            this._a("actualContentPaddingRight", this.i.h0);
        }
        get contentPaddingBottom() {
            return this.i.h2;
        }
        set contentPaddingBottom(v) {
            this.i.h2 = +v;
            this._a("contentPaddingBottom", this.i.h2);
        }
        get actualContentPaddingBottom() {
            return this.i.hy;
        }
        set actualContentPaddingBottom(v) {
            this.i.hy = +v;
            this._a("actualContentPaddingBottom", this.i.hy);
        }
        cleanUp() {
            this.i.e3();
        }
        openSubMenu() {
            this.i.fy();
        }
        closeSubmenu() {
            this.i.e5();
        }
        exportVisualData() {
            let iv = this.i.cn();
            return (iv);
        }
    }
    IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent = null;
    IgcToolActionIconButtonComponent.htmlTagName = "igc-tool-action-icon-button";
    IgcToolActionIconButtonComponent._isElementRegistered = false;
    return IgcToolActionIconButtonComponent;
})();

==> igniteui-webcomponents-layouts-5.1.0.tgz: package/esm2015/lib/igc-tool-action-icon-button-component.js <==
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionIconButton } from "./ToolActionIconButton";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
export let IgcToolActionIconButtonComponent = /*@__PURE__*/ (() => {
    class IgcToolActionIconButtonComponent extends IgcToolActionComponent {
        createImplementation() {
            return new ToolActionIconButton();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent == null) {
                let names = getAllPropertyNames(IgcToolActionIconButtonComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent = names;
            }
            return IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent;
        }
        static register() {
            if (!IgcToolActionIconButtonComponent._isElementRegistered) {
                IgcToolActionIconButtonComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcToolActionIconButtonComponent.htmlTagName, IgcToolActionIconButtonComponent);
            }
        }
        /**
         * Gets or sets how long it takes before the tooltip is displayed (in milliseconds).
        */
        get tooltipDelay() {
            return this.i.ic;
        }
        set tooltipDelay(v) {
            this.i.ic = +v;
            this._a("tooltipDelay", this.i.ic);
        }
        /**
         * Gets the actual delay before the tooltip is displayed (in milliseconds).
        */
        get actualTooltipDelay() {
            return this.i.ib;
        }
        set actualTooltipDelay(v) {
            this.i.ib = +v;
            this._a("actualTooltipDelay", this.i.ib);
        }
        get contentPaddingLeft() {
            return this.i.h4;
        }
        set contentPaddingLeft(v) {
            this.i.h4 = +v;
            this._a("contentPaddingLeft", this.i.h4);
        }
        get actualContentPaddingLeft() {
            return this.i.h0;
        }
        set actualContentPaddingLeft(v) {
            this.i.h0 = +v;
            this._a("actualContentPaddingLeft", this.i.h0);
        }
        get contentPaddingTop() {
            return this.i.h6;
        }
        set contentPaddingTop(v) {
            this.i.h6 = +v;
            this._a("contentPaddingTop", this.i.h6);
        }
        get actualContentPaddingTop() {
            return this.i.h2;
        }
        set actualContentPaddingTop(v) {
            this.i.h2 = +v;
            this._a("actualContentPaddingTop", this.i.h2);
        }
        get contentPaddingRight() {
            return this.i.h5;
        }
        set contentPaddingRight(v) {
            this.i.h5 = +v;
            this._a("contentPaddingRight", this.i.h5);
        }
        get actualContentPaddingRight() {
            return this.i.h1;
        }
        set actualContentPaddingRight(v) {
            this.i.h1 = +v;
            this._a("actualContentPaddingRight", this.i.h1);
        }
        get contentPaddingBottom() {
            return this.i.h3;
        }
        set contentPaddingBottom(v) {
            this.i.h3 = +v;
            this._a("contentPaddingBottom", this.i.h3);
        }
        get actualContentPaddingBottom() {
            return this.i.hz;
        }
        set actualContentPaddingBottom(v) {
            this.i.hz = +v;
            this._a("actualContentPaddingBottom", this.i.hz);
        }
        cleanUp() {
            this.i.e3();
        }
        openSubMenu() {
            this.i.fy();
        }
        closeSubmenu() {
            this.i.e5();
        }
        exportVisualData() {
            let iv = this.i.cn();
            return (iv);
        }
    }
    IgcToolActionIconButtonComponent._observedAttributesIgcToolActionIconButtonComponent = null;
    IgcToolActionIconButtonComponent.htmlTagName = "igc-tool-action-icon-button";
    IgcToolActionIconButtonComponent._isElementRegistered = false;
    return IgcToolActionIconButtonComponent;
})();
